@@ -49,38 +49,14 @@
  */
 void
 eel_fill_rectangle (GdkDrawable *drawable,
-			 GdkGC *gc,
-			 const GdkRectangle *rectangle)
+		    GdkGC *gc,
+		    const GdkRectangle *rectangle)
 {
 	gdk_draw_rectangle (drawable, gc, TRUE,
 			    rectangle->x, rectangle->y,
 			    rectangle->width, rectangle->height);
 }
 
-/**
- * eel_fill_rectangle_with_color:
- * @drawable: Target to draw into.
- * @gc: Graphics context (mainly for clip).
- * @rectangle: Rectangle to fill.
- * @color: Color to fill with.
- *
- * Fill the rectangle with a color.
- * Convenient when you have a GdkRectangle structure.
- */
-void
-eel_fill_rectangle_with_color (GdkDrawable *drawable,
-			       GdkGC *gc,
-			       const GdkRectangle *rectangle,
-			       guint32 rgb)
-{
-	GdkGCValues saved_values;
-	
-	gdk_gc_get_values (gc, &saved_values);
-	gdk_rgb_gc_set_foreground (gc, rgb);
-	eel_fill_rectangle (drawable, gc, rectangle);
-	gdk_gc_set_foreground (gc, &saved_values.foreground);
-}
-
 /**
  * eel_rectangle_contains:
  * @rectangle: Rectangle possibly containing a point.
@@ -111,8 +87,8 @@ eel_rectangle_contains (const GdkRectangle *rectangle,
  */
 void
 eel_rectangle_inset (GdkRectangle *rectangle, 
-			  int x, 
-			  int y)
+		     int x, 
+		     int y)
 {
 	g_return_if_fail (rectangle != NULL);
 
@@ -136,8 +112,8 @@ eel_rectangle_inset (GdkRectangle *rectangle,
  */
 guint32
 eel_interpolate_color (gdouble ratio,
-			    guint32 start_rgb,
-			    guint32 end_rgb)
+		       guint32 start_rgb,
+		       guint32 end_rgb)
 {
 	guchar red, green, blue;
 
@@ -415,11 +391,8 @@ eel_gdk_color_parse_with_white_default (const char *color_spec,
 
 	got_color = FALSE;
 	if (color_spec != NULL) {
-		if (gdk_color_parse (color_spec, color)) {
+		if (eel_gdk_color_parse (color_spec, color)) {
 			got_color = TRUE;
-		} else if (eel_str_has_prefix (color_spec, "rgb:")) {
-			/* put rgb: parsing here? */
-			g_warning ("do we need rgb: parsing?");
 		}
 	}
 
@@ -578,65 +551,6 @@ eel_gdk_color_is_dark (GdkColor *color)
 	return intensity < 128;
 }
 
-/**
- * eel_gdk_choose_foreground_color:
- *
- * Select a foreground color given that BACKGROUND is the background
- * color. If the PREFERRED color has a high enough contrast with
- * BACKGROUND, use it, else use one of black or white, depending on
- * the darkness of BACKGROUND.
- *
- * The selected color is stored in PREFERRED.
- */
-void
-eel_gdk_choose_foreground_color (GdkColor *preferred,
-				      GdkColor *background)
-{
-	gboolean preferred_is_dark, background_is_dark;
-
-	preferred_is_dark = eel_gdk_color_is_dark (preferred);
-	background_is_dark = eel_gdk_color_is_dark (background);
-
-	if (preferred_is_dark == background_is_dark) {
-		/* Colors are too similar, so choose a different fg.
-		 * Currently hardcoded to use either white or black.
-		 */
-		if (preferred_is_dark) {
-			preferred->red = 65535;
-			preferred->green = 65535;
-			preferred->blue = 65535;
-		} else {
-			preferred->red = 0;
-			preferred->green = 0;
-			preferred->blue = 0;
-		}
-	}
-}
-
-/**
- * eel_gdk_gc_choose_foreground_color:
- *
- * Use eel_gdk_color_choose_foreground_color () to set the
- * foreground color of GC to something suitable, given that BACKGROUND
- * will be the background color and PREFERRED is the preferred color.
- *
- * Uses GdkRGB to install the color value.
- */
-void
-eel_gdk_gc_choose_foreground_color (GdkGC *gc,
-					 GdkColor *preferred,
-					 GdkColor *background)
-{
-	GdkColor temp;
-	guint32 rgb;
-
-	temp = *preferred;
-	eel_gdk_choose_foreground_color (&temp, background);
-	rgb = eel_gdk_color_to_rgb (&temp);
-
-	gdk_rgb_gc_set_foreground (gc, rgb);
-}
-
 /**
  * eel_stipple_bitmap:
  * 
@@ -827,6 +741,41 @@ eel_gdk_parse_geometry (const char *string, int *x_return, int *y_return,
 	return gdk_flags;
 }
 
+/* Color specifications have changed in gdk 2.0.  Unfortunately, nautilus has
+   the old rgb:RRRR/BBBB/GGGG format scattered about in various xml files and
+   the new gdk_color_parse () is not fully backward compatible. */
+
+/* 2002-13-02 FIXME: Someday we should remove this compatibility code. */
+
+gboolean
+eel_gdk_color_parse (const gchar *spec,
+		     GdkColor *color)
+{
+	Colormap xcolormap;
+	XColor xcolor;
+
+	g_return_val_if_fail (spec != NULL, FALSE);
+	g_return_val_if_fail (color != NULL, FALSE);
+
+	/* First try to use the new gdk code. */
+	if (gdk_color_parse (spec, color)) {
+		return TRUE;
+	}
+
+	/* If that failed, fallback to the old gdk code. */
+	xcolormap = DefaultColormap (GDK_DISPLAY (),
+				     gdk_x11_get_default_screen ());
+
+	if (XParseColor (GDK_DISPLAY (), xcolormap, spec, &xcolor)) {
+		color->red = xcolor.red;
+		color->green = xcolor.green;
+		color->blue = xcolor.blue;
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
 #if ! defined (EEL_OMIT_SELF_CHECK)
 
 static char *
