@@ -80,7 +80,7 @@ static void load_done            (EelPixbufLoadHandle *handle,
 void
 eel_gdk_pixbuf_list_ref (GList *pixbuf_list)
 {
-	g_list_foreach (pixbuf_list, (GFunc) gdk_pixbuf_ref, NULL);
+	g_list_foreach (pixbuf_list, (GFunc) g_object_ref, NULL);
 }
 
 /**
@@ -92,7 +92,7 @@ eel_gdk_pixbuf_list_ref (GList *pixbuf_list)
 void
 eel_gdk_pixbuf_list_free (GList *pixbuf_list)
 {
-	eel_g_list_free_deep_custom (pixbuf_list, (GFunc) gdk_pixbuf_unref, NULL);
+	eel_g_list_free_deep_custom (pixbuf_list, (GFunc) g_object_unref, NULL);
 }
 
 GdkPixbuf *
@@ -426,7 +426,7 @@ eel_gdk_pixbuf_get_dimensions (const GdkPixbuf *pixbuf)
 }
 
 /**
- * eel_gdk_pixbuf_fill_rectangle:
+ * eel_gdk_pixbuf_fill_rectangle_with_color:
  * @pixbuf: Target pixbuf to fill into.
  * @area: Rectangle to fill.
  * @color: The color to use.
@@ -778,7 +778,7 @@ eel_gdk_pixbuf_draw_to_pixbuf_alpha (const GdkPixbuf *pixbuf,
 		
 		pixbuf = eel_gdk_pixbuf_new_from_pixbuf_sub_area ((GdkPixbuf *) pixbuf, area);
 	} else {
-		gdk_pixbuf_ref ((GdkPixbuf *) pixbuf);
+		g_object_ref (G_OBJECT (pixbuf));
 	}
 	
 	gdk_pixbuf_composite (pixbuf,
@@ -794,17 +794,17 @@ eel_gdk_pixbuf_draw_to_pixbuf_alpha (const GdkPixbuf *pixbuf,
 			      interpolation_mode,
 			      opacity);
 
-	gdk_pixbuf_unref ((GdkPixbuf *) pixbuf);
+	g_object_unref (G_OBJECT (pixbuf));
 }
 
 static void
-pixbuf_destroy_callback (guchar *pixels,
+pixbuf_destroy_callback (guchar  *pixels,
 			 gpointer callback_data)
 {
 	g_return_if_fail (pixels != NULL);
 	g_return_if_fail (callback_data != NULL);
 
-	gdk_pixbuf_unref ((GdkPixbuf *) callback_data);
+	g_object_unref (callback_data);
 }
 
 /**
@@ -1291,34 +1291,38 @@ eel_gdk_pixbuf_intersect (const GdkPixbuf *pixbuf,
 }
 
 /**
- * eel_gdk_pixbuf_draw_layout
- * @pixbuf:    the pixbuf on which to draw the layout
- * @x:         the X position of the left of the layout (in pixels)
- * @y:         the Y position of the top of the layout (in pixels)
- * @color:     the color to use to draw the text, in "eel RGB" format
- * @layout:    a #PangoLayout
- *
- * Render a #PangoLayout onto a #GdkPixbuf.
- */
+ * eel_gdk_pixbuf_draw_layout_clipped:
+ * @pixbuf: the pixbuf to render to
+ * @region: text crop region
+ * @color: the color to render the text
+ * @layout: the text
+ * 
+ * This method renders the text in @layout into the
+ * @pixbuf with @color cropping it to @region.
+ **/
 void
-eel_gdk_pixbuf_draw_layout (GdkPixbuf *pixbuf,
-			    int x, int y,
-			    guint32 color,
-			    PangoLayout *layout)
+eel_gdk_pixbuf_draw_layout_clipped (GdkPixbuf   *pixbuf,
+				    ArtIRect     region,
+				    guint32      color,
+				    PangoLayout *layout)
 {
 	PangoRectangle ink_rect;
-	int pixbuf_height, pixbuf_width;
 	FT_Bitmap ink_bitmap;
 	GdkPixbuf *ink_pixbuf;
 	int bx, by;
+	int pixbuf_width, pixbuf_height;
 	const guint8 *ps;
 	guint8 *pd;
 	guint8 r, g, b;
+
+	if (region.x1 <= region.x0 || region.y1 <= region.y0) {
+		return;
+	}
 	
 	pango_layout_get_pixel_extents (layout, &ink_rect, NULL);
 
-	ink_rect.x += x;
-	ink_rect.y += y;
+	ink_rect.x += region.x0;
+	ink_rect.y += region.y0;
 
 	/* Do an intersect operation the long way.
 	 * Sad to write this all out like this.
@@ -1357,7 +1361,9 @@ eel_gdk_pixbuf_draw_layout (GdkPixbuf *pixbuf,
 	ink_bitmap.num_grays = 0x100;
 	ink_bitmap.pixel_mode = ft_pixel_mode_grays;
 
-	pango_ft2_render_layout (&ink_bitmap, layout, x - ink_rect.x, y - ink_rect.y);
+	pango_ft2_render_layout (&ink_bitmap, layout,
+				 region.x0 - ink_rect.x,
+				 region.y0 - ink_rect.y);
 
 	ink_pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8,
 				     ink_bitmap.width, ink_bitmap.rows);
@@ -1382,13 +1388,39 @@ eel_gdk_pixbuf_draw_layout (GdkPixbuf *pixbuf,
 
 	gdk_pixbuf_composite (ink_pixbuf, pixbuf,
 			      ink_rect.x, ink_rect.y,
-			      ink_bitmap.width, ink_bitmap.rows,
+			      MIN (region.x1 - region.x0, ink_bitmap.width),
+			      MIN (region.y1 - region.y0, ink_bitmap.rows),
 			      ink_rect.x, ink_rect.y,
-			      1, 1, GDK_INTERP_BILINEAR, 0xFF);
+			      1.0, 1.0, GDK_INTERP_BILINEAR, 0xFF);
 
 	g_object_unref (ink_pixbuf);
 }
 
+/**
+ * eel_gdk_pixbuf_draw_layout
+ * @pixbuf:    the pixbuf on which to draw the layout
+ * @x:         the X position of the left of the layout (in pixels)
+ * @y:         the Y position of the top of the layout (in pixels)
+ * @color:     the color to use to draw the text, in "eel RGB" format
+ * @layout:    a #PangoLayout
+ *
+ * Render a #PangoLayout onto a #GdkPixbuf.
+ */
+void
+eel_gdk_pixbuf_draw_layout (GdkPixbuf *pixbuf,
+			    int x, int y,
+			    guint32 color,
+			    PangoLayout *layout)
+{
+	ArtIRect region;
+
+	region.x0 = x;
+	region.y0 = y;
+	region.x1 = region.y1 = G_MAXINT;
+
+	eel_gdk_pixbuf_draw_layout_clipped (pixbuf, region, color, layout);
+}
+
 #if !defined (EEL_OMIT_SELF_CHECK)
 
 static char *
