@@ -27,6 +27,7 @@
 #include <config.h>
 #include "eel-glib-extensions.h"
 
+#include "eel-debug.h"
 #include "eel-lib-self-check-functions.h"
 #include "eel-string.h"
 #include <libgnome/gnome-i18n.h>
@@ -166,12 +167,17 @@ eel_strdup_strftime (const char *format, struct tm *time_pieces)
 	GString *string;
 	const char *remainder, *percent;
 	char code[3], buffer[512];
-	char *piece, *result;
+	char *piece, *result, *converted;
 	size_t string_length;
 	gboolean strip_leading_zeros, turn_leading_zeros_to_spaces;
 
+	/* Format could be translated, and contain UTF-8 chars,
+	 * so convert to locale encoding which strftime uses */
+	converted = g_locale_from_utf8 (format, -1, NULL, NULL, NULL);
+	g_return_val_if_fail (converted != NULL, NULL);
+	
 	string = g_string_new ("");
-	remainder = format;
+	remainder = converted;
 
 	/* Walk from % character to % character. */
 	for (;;) {
@@ -261,10 +267,13 @@ eel_strdup_strftime (const char *format, struct tm *time_pieces)
 		/* Add this piece. */
 		g_string_append (string, piece);
 	}
+	
+	/* Convert the string back into utf-8. */
+	result = g_locale_to_utf8 (string->str, -1, NULL, NULL, NULL);
+
+	g_string_free (string, TRUE);
+	g_free (converted);
 
-	/* Extract the string. */
-	result = string->str;
-	g_string_free (string, FALSE);
 	return result;
 }
 
@@ -318,29 +327,6 @@ eel_g_list_equal (GList *list_a, GList *list_b)
 	return p == NULL && q == NULL;
 }
 
-/**
- * eel_g_list_copy
- *
- * @list: List to copy.
- * Return value: Shallow copy of @list.
- **/
-GList *
-eel_g_list_copy (GList *list)
-{
-	GList *p, *result;
-
-	result = NULL;
-	
-	if (list == NULL) {
-		return NULL;
-	}
-
-	for (p = g_list_last (list); p != NULL; p = p->prev) {
-		result = g_list_prepend (result, p->data);
-	}
-	return result;
-}
-
 /**
  * eel_g_str_list_equal
  *
@@ -584,98 +570,6 @@ eel_g_list_partition (GList *list,
 	return predicate_true;
 }
 
-
-
-/**
- * eel_g_ptr_array_new_from_list
- * 
- * Copies (shallow) a list of pointers into an array of pointers.
- * 
- * @list: List to copy.
- * 
- * Return value: GPtrArray containing a copy of all the pointers
- * from @list
- */
-GPtrArray *
-eel_g_ptr_array_new_from_list (GList *list)
-{
-	GPtrArray *array;
-	int size;
-	int index;
-	GList *p;
-
-	array = g_ptr_array_new ();
-	size = g_list_length ((GList *)list);
-
-	g_ptr_array_set_size (array, size);
-
-	for (p = list, index = 0; p != NULL; p = p->next, index++) {
-		g_ptr_array_index (array, index) = p->data;
-	}
-
-	return array;
-}
-
-/**
- * eel_g_ptr_array_search
- * 
- * Does a binary search through @array looking for an item
- * that matches a predicate consisting of a @search_function and
- * @context. May be used to find an insertion point 
- * 
- * @array: pointer array to search
- * @search_function: search function called on elements
- * @context: search context passed to the @search_function containing
- * the key or other data we are matching
- * @match_only: if TRUE, only returns a match if the match is exact,
- * if FALSE, returns either an index of a match or an index of the
- * slot a new item should be inserted in
- * 
- * Return value: index of the match or -1 if not found
- */
-int
-eel_g_ptr_array_search (GPtrArray *array, 
-			     EelSearchFunction search_function,
-			     void *context,
-			     gboolean match_only)
-{
-	int r, l;
-	int resulting_index;
-	int compare_result;
-	void *item;
-
-	r = array->len - 1;
-	item = NULL;
-	resulting_index = 0;
-	compare_result = 0;
-	
-	for (l = 0; l <= r; ) {
-		resulting_index = (l + r) / 2;
-
-		item = g_ptr_array_index (array, resulting_index);
-
-		compare_result = (search_function) (item, context);
-		
-		if (compare_result > 0) {
-			r = resulting_index - 1;
-		} else if (compare_result < 0) {
-			l = resulting_index + 1;
-		} else {
-			return resulting_index;
-		}
-	}
-
-	if (compare_result < 0) {
-		resulting_index++;
-	}
-
-	if (match_only && compare_result != 0) {
-		return -1;
-	}
-
-	return resulting_index;
-}
-
 /**
  * eel_get_system_time
  * 
@@ -743,9 +637,8 @@ eel_g_hash_table_new_free_at_exit (GHashFunc hash_func,
 	 * have fixed more of the leaks. For now, it's a bit too noisy
 	 * for the general public.
 	 */
-	if (hash_tables_to_free_at_exit == NULL
-	    && g_getenv ("NAUTILUS_DEBUG") != NULL) {
-		g_atexit (free_hash_tables_at_exit);
+	if (hash_tables_to_free_at_exit == NULL) {
+		eel_debug_call_at_shutdown (free_hash_tables_at_exit);
 	}
 
 	hash_table = g_hash_table_new (hash_func, key_compare_func);
