@@ -66,32 +66,6 @@ struct IconSelectionData {
 
 typedef struct IconSelectionData IconSelectionData;
 
-ArtIRect
-eel_gnome_canvas_world_to_window_rectangle (GnomeCanvas *canvas,
-					    ArtDRect world_rect)
-{
-	double x0, y0, x1, y1;
-	ArtIRect window_rect;
-
-	g_return_val_if_fail (GNOME_IS_CANVAS (canvas), eel_art_irect_empty);
-
-	gnome_canvas_world_to_window (canvas,
-				      world_rect.x0,
-				      world_rect.y0,
-				      &x0, &y0);
-	gnome_canvas_world_to_window (canvas,
-				      world_rect.x1,
-				      world_rect.y1,
-				      &x1, &y1);
-
-	window_rect.x0 = x0;
-	window_rect.y0 = y0;
-	window_rect.x1 = x1;
-	window_rect.y1 = y1;
-
-	return window_rect;
-}
-
 ArtIRect
 eel_gnome_canvas_world_to_canvas_rectangle (GnomeCanvas *canvas,
 					    ArtDRect world_rect)
@@ -541,7 +515,7 @@ try_terminal_command (const char *program,
 		return NULL;
 	}
 
-	program_in_path = gnome_is_program_in_path (program);
+	program_in_path = g_find_program_in_path (program);
 	if (program_in_path == NULL) {
 		return NULL;
 	}
@@ -592,7 +566,7 @@ get_terminal_command_prefix (gboolean for_command)
 	char *command;
 	guint i;
 	static const char *const commands[][3] = {
-		{ "gnome-terminal", "--start-factory-server --use-factory -x", "--login" },
+		{ "gnome-terminal", "-x",                                      "" },
 		{ "dtterm",         "-e",                                      "-ls" },
 		{ "nxterm",         "-e",                                      "-ls" },
 		{ "color-xterm",    "-e",                                      "-ls" },
@@ -809,7 +783,7 @@ eel_gnome_icon_selector_new (const char *title,
 					      GTK_STOCK_OK, GTK_RESPONSE_OK,
 					      NULL);
 
-	gtk_window_set_policy (GTK_WINDOW (dialog), TRUE, TRUE, TRUE);
+	gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
 
 	icon_selection = gnome_icon_selection_new();
 
@@ -847,18 +821,15 @@ eel_gnome_icon_selector_new (const char *title,
 	
 	gnome_icon_selection_show_icons (GNOME_ICON_SELECTION (icon_selection));
 
-	gtk_signal_connect (GTK_OBJECT (dialog), "response",
-			    G_CALLBACK (dialog_response_callback),
-			    selection_data);
+	g_signal_connect (dialog, "response",
+			  G_CALLBACK (dialog_response_callback), selection_data);
 
-	gtk_signal_connect_after(GTK_OBJECT (gnome_icon_selection_get_gil (GNOME_ICON_SELECTION (selection_data->icon_selection))),
-				 "select_icon",
-				 G_CALLBACK(list_icon_selected_callback),
-				 selection_data);
+	g_signal_connect_after (gnome_icon_selection_get_gil (GNOME_ICON_SELECTION (selection_data->icon_selection)),
+				"select_icon",
+				G_CALLBACK (list_icon_selected_callback), selection_data);
 
-	gtk_signal_connect_while_alive( GTK_OBJECT (entry), "activate",
-					G_CALLBACK(entry_activated),
-					selection_data, GTK_OBJECT (file_entry));
+	g_signal_connect (entry, "activate",
+			  G_CALLBACK (entry_activated), selection_data);
 
 	return dialog;
 }
@@ -910,36 +881,36 @@ eel_gnome_canvas_item_send_behind (GnomeCanvasItem *item,
 }
 
 ArtIRect
-eel_gnome_canvas_world_to_canvas_window_rectangle (GnomeCanvas *canvas,
-						   ArtDRect world_rect)
+eel_gnome_canvas_world_to_widget_rectangle (GnomeCanvas *canvas,
+					    ArtDRect world_rect)
 {
-	ArtIRect window_rect;
+	ArtIRect widget_rect;
 	
 	g_return_val_if_fail (GNOME_IS_CANVAS (canvas), eel_art_irect_empty);
 
-	eel_gnome_canvas_world_to_canvas_window (canvas,
-						 world_rect.x0, world_rect.y0,
-						 &window_rect.x0, &window_rect.y0);
-	eel_gnome_canvas_world_to_canvas_window (canvas,
-						 world_rect.x1, world_rect.y1,
-						 &window_rect.x1, &window_rect.y1);
+	eel_gnome_canvas_world_to_widget (canvas,
+					  world_rect.x0, world_rect.y0,
+					  &widget_rect.x0, &widget_rect.y0);
+	eel_gnome_canvas_world_to_widget (canvas,
+					  world_rect.x1, world_rect.y1,
+					  &widget_rect.x1, &widget_rect.y1);
 
-	return window_rect;
+	return widget_rect;
 }
 
 void
-eel_gnome_canvas_canvas_window_to_world (GnomeCanvas *canvas,
-					 int          window_x,
-					 int          window_y,
-					 double      *world_x,
-					 double      *world_y)
+eel_gnome_canvas_widget_to_world (GnomeCanvas *canvas,
+				  int          widget_x,
+				  int          widget_y,
+				  double      *world_x,
+				  double      *world_y)
 {
 	int bin_window_x, bin_window_y;
 	
 	g_return_if_fail (GNOME_IS_CANVAS (canvas));
 
-	bin_window_x = window_x + gtk_adjustment_get_value (gtk_layout_get_hadjustment (GTK_LAYOUT (canvas)));
-	bin_window_y = window_y + gtk_adjustment_get_value (gtk_layout_get_vadjustment (GTK_LAYOUT (canvas)));
+	bin_window_x = widget_x + gtk_adjustment_get_value (gtk_layout_get_hadjustment (GTK_LAYOUT (canvas)));
+	bin_window_y = widget_y + gtk_adjustment_get_value (gtk_layout_get_vadjustment (GTK_LAYOUT (canvas)));
 
 	gnome_canvas_window_to_world (canvas,
 				      bin_window_x, bin_window_y,
@@ -947,11 +918,11 @@ eel_gnome_canvas_canvas_window_to_world (GnomeCanvas *canvas,
 }
 
 void
-eel_gnome_canvas_world_to_canvas_window (GnomeCanvas *canvas,
-					 double       world_x,
-					 double       world_y,
-					 int         *window_x,
-					 int         *window_y)
+eel_gnome_canvas_world_to_widget (GnomeCanvas *canvas,
+				  double       world_x,
+				  double       world_y,
+				  int         *widget_x,
+				  int         *widget_y)
 {
 	double bin_window_x, bin_window_y;
 
@@ -961,10 +932,10 @@ eel_gnome_canvas_world_to_canvas_window (GnomeCanvas *canvas,
 				      world_x, world_y,
 				      &bin_window_x, &bin_window_y);
 
-	if (window_x) {
-		*window_x = (int) bin_window_x - gtk_adjustment_get_value (gtk_layout_get_hadjustment (GTK_LAYOUT (canvas)));
+	if (widget_x) {
+		*widget_x = (int) bin_window_x - gtk_adjustment_get_value (gtk_layout_get_hadjustment (GTK_LAYOUT (canvas)));
 	}
-	if (window_y) {
-		*window_y = (int) bin_window_y - gtk_adjustment_get_value (gtk_layout_get_vadjustment (GTK_LAYOUT (canvas)));
+	if (widget_y) {
+		*widget_y = (int) bin_window_y - gtk_adjustment_get_value (gtk_layout_get_vadjustment (GTK_LAYOUT (canvas)));
 	}
 }
