@@ -33,7 +33,7 @@
 /* icon selection callback function. */
 typedef void (* EelIconSelectionFunction) (const char *icon_path, gpointer callback_data);
 
-/* Causes an update as needed. The GnomeCanvas code says it should, but it doesn't. */
+/* Causes an update as needed. The GnomeCanvas code says it does this, but it doesn't. */
 void          eel_gnome_canvas_set_scroll_region                      (GnomeCanvas              *canvas,
 								       double                    x1,
 								       double                    y1,
@@ -62,27 +62,43 @@ void          eel_gnome_canvas_item_request_update_deep               (GnomeCanv
  * always returns the bounds * in world coordinates and it returns
  * them in a single rectangle.
  */
-ArtDRect      eel_gnome_canvas_item_get_world_bounds                  (const GnomeCanvasItem    *item);
+ArtDRect      eel_gnome_canvas_item_get_world_bounds                  (GnomeCanvasItem          *item);
 
 /* This returns the current canvas bounds as computed by update.
  * It's not as "up to date" as get_bounds, which is accurate even
  * before an update happens.
  */
-ArtIRect      eel_gnome_canvas_item_get_current_canvas_bounds         (const GnomeCanvasItem    *item);
+ArtIRect      eel_gnome_canvas_item_get_current_canvas_bounds         (GnomeCanvasItem          *item);
 
 /* This returns the canvas bounds in a slower way that's always up to
  * date, even before an update.
  */
-ArtIRect      eel_gnome_canvas_item_get_canvas_bounds                 (const GnomeCanvasItem    *item);
+ArtIRect      eel_gnome_canvas_item_get_canvas_bounds                 (GnomeCanvasItem          *item);
 
 /* Convenience functions for doing things with whole rectangles. */
-ArtIRect      eel_gnome_canvas_world_to_canvas_rectangle              (const GnomeCanvas        *canvas,
-								       ArtDRect                  world_rectangle);
-ArtIRect      eel_gnome_canvas_world_to_window_rectangle              (const GnomeCanvas        *canvas,
+ArtIRect      eel_gnome_canvas_world_to_canvas_rectangle              (GnomeCanvas              *canvas,
 								       ArtDRect                  world_rectangle);
 void          eel_gnome_canvas_request_redraw_rectangle               (GnomeCanvas              *canvas,
 								       ArtIRect                  canvas_rectangle);
 
+/* Often, it's more useful to have coordinates in widget terms, rateher than world, canvas, or bin window terms. */
+void          eel_gnome_canvas_widget_to_world                        (GnomeCanvas              *canvas,
+								       int                       widget_x,
+								       int                       widget_y,
+								       double                   *world_x,
+								       double                   *world_y);
+void          eel_gnome_canvas_world_to_widget                        (GnomeCanvas              *canvas,
+								       double                    world_x,
+								       double                    world_y,
+								       int                      *widget_x,
+								       int                      *widget_y);
+ArtIRect      eel_gnome_canvas_world_to_widget_rectangle              (GnomeCanvas              *canvas,
+								       ArtDRect                  world_rectangle);
+
+/* Function for moving a canvas item relative to another existing item. */
+void          eel_gnome_canvas_item_send_behind                       (GnomeCanvasItem          *item,
+								       GnomeCanvasItem          *behind_item);
+
 /* Requests the entire object be redrawn.
  * Normally, you use request_update when calling from outside the canvas item
  * code. This is for within canvas item code.
