@@ -100,20 +100,17 @@ eel_gtk_button_set_padding (GtkButton *button, int pad_amount)
  * @destroy_func: the function to call on the user data when the signal
  * is disconnected.
  **/
-guint eel_gtk_signal_connect_free_data_custom (GtkObject *object,
-				  	     	    const gchar *name,
-				  	     	    GtkSignalFunc func,
-				  	     	    gpointer data,
-				  	     	    GtkDestroyNotify destroy_func)
+guint
+eel_gtk_signal_connect_free_data_custom (GtkObject       *object,
+					 const gchar     *name,
+					 GtkSignalFunc    func,
+					 gpointer         data,
+					 GtkDestroyNotify destroy_func)
 {
-	return gtk_signal_connect_full (object, 
-					name, 
-					func, 
-					NULL, /* marshal */
-					data, 
-					destroy_func, 
-					FALSE, /* is this an object signal? */
-					FALSE); /* invoke func after signal? */
+	return g_signal_connect_closure (
+		object, name,
+		g_cclosure_new (func, data, (GClosureNotify) destroy_func),
+		FALSE);
 }
 
 /**
@@ -194,8 +191,8 @@ handle_standard_close_accelerator (GtkWindow *window,
 
 	if (eel_gtk_window_event_is_close_accelerator (window, event)) {
 		send_delete_event (window);
-		gtk_signal_emit_stop_by_name 
-			(GTK_OBJECT (window), "key_press_event");
+		g_signal_stop_emission_by_name (
+			G_OBJECT (window), "key_press_event");
 		return TRUE;
 	}
 
@@ -416,36 +413,6 @@ eel_gtk_window_set_initial_geometry_from_string (GtkWindow *window,
 	eel_gtk_window_set_initial_geometry (window, geometry_flags, left, top, width, height);
 }
 
-/**
- * eel_gtk_selection_data_copy_deep:
- * 
- * Copies a GtkSelectionData, and copies the data too.
- * @data: The GtkSelectionData to be copied.
- **/
-GtkSelectionData *
-eel_gtk_selection_data_copy_deep (const GtkSelectionData *data)
-{
-	GtkSelectionData *copy;
-
-	copy = g_new0 (GtkSelectionData, 1);
-	gtk_selection_data_set (copy, data->type, data->format, data->data, data->length);
-
-	return copy;
-}
-
-/**
- * eel_gtk_selection_data_free_deep:
- * 
- * Frees a GtkSelectionData, and frees the data too.
- * @data: The GtkSelectionData to be freed.
- **/
-void
-eel_gtk_selection_data_free_deep (GtkSelectionData *data)
-{
-	g_free (data->data);
-	gtk_selection_data_free (data);
-}
-
 /**
  * eel_gtk_signal_connect_free_data:
  * 
@@ -571,7 +538,7 @@ eel_gtk_menu_set_item_visibility (GtkMenu *menu, int index, gboolean visible)
 
 	g_return_if_fail (GTK_IS_MENU (menu));
 
-	children = gtk_container_children (GTK_CONTAINER (menu));
+	children = gtk_container_get_children (GTK_CONTAINER (menu));
 	g_return_if_fail (index >= 0 && index < (int) g_list_length (children));
 
 	menu_item = GTK_WIDGET (g_list_nth_data (children, index));
@@ -728,9 +695,9 @@ alive_disconnecter (GtkObject *object, DisconnectInfo *info)
 	g_assert (info->disconnect_handler2 != 0);
 	g_assert (object == info->object1 || object == info->object2);
 	
-	gtk_signal_disconnect (info->object1, info->disconnect_handler1);
-	gtk_signal_disconnect (info->object1, info->signal_handler);
-	gtk_signal_disconnect (info->object2, info->disconnect_handler2);
+	g_signal_handler_disconnect (info->object1, info->disconnect_handler1);
+	g_signal_handler_disconnect (info->object1, info->signal_handler);
+	g_signal_handler_disconnect (info->object2, info->disconnect_handler2);
 	
 	g_free (info);
 }
@@ -764,22 +731,22 @@ eel_gtk_signal_connect_full_while_alive (GtkObject *object,
 	info->object1 = object;
 	info->object2 = alive_object;
 	
-	info->signal_handler = gtk_signal_connect_full (object,
-							name,
-							func,
-							marshal,
-							data,
-							destroy_func,
-							object_signal,
-							after);
-	info->disconnect_handler1 = gtk_signal_connect (object,
-							"destroy",
-							G_CALLBACK (alive_disconnecter),
-							info);
-	info->disconnect_handler2 = gtk_signal_connect (alive_object,
-							"destroy",
-							G_CALLBACK (alive_disconnecter),
-							info);
+
+	info->signal_handler = g_signal_connect_closure (
+		object, name,
+		(object_signal
+		 ? g_cclosure_new_swap
+		 : g_cclosure_new) (func, data, (GClosureNotify) destroy_func),
+		after);
+
+	info->disconnect_handler1 = g_signal_connect (G_OBJECT (object),
+						      "destroy",
+						      G_CALLBACK (alive_disconnecter),
+						      info);
+	info->disconnect_handler2 = g_signal_connect (G_OBJECT (alive_object),
+						      "destroy",
+						      G_CALLBACK (alive_disconnecter),
+						      info);
 }
 
 typedef struct
@@ -806,10 +773,10 @@ while_realized_disconnecter (GtkObject *object,
 	g_return_if_fail (info->realized_widget_destroy_handler != 0);
 	g_return_if_fail (info->realized_widget_unrealized_handler != 0);
 
- 	gtk_signal_disconnect (info->object, info->object_destroy_handler);
- 	gtk_signal_disconnect (info->object, info->signal_handler);
- 	gtk_signal_disconnect (GTK_OBJECT (info->realized_widget), info->realized_widget_destroy_handler);
- 	gtk_signal_disconnect (GTK_OBJECT (info->realized_widget), info->realized_widget_unrealized_handler);
+ 	g_signal_handler_disconnect (info->object, info->object_destroy_handler);
+ 	g_signal_handler_disconnect (info->object, info->signal_handler);
+ 	g_signal_handler_disconnect (info->realized_widget, info->realized_widget_destroy_handler);
+ 	g_signal_handler_disconnect (info->realized_widget, info->realized_widget_unrealized_handler);
 	g_free (info);
 }
 
@@ -849,24 +816,25 @@ eel_gtk_signal_connect_while_realized (GtkObject *object,
 	
 	info->object = object;
 	info->object_destroy_handler = 
-		gtk_signal_connect (info->object,
-				    "destroy",
-				    G_CALLBACK (while_realized_disconnecter),
-				    info);
+		g_signal_connect (G_OBJECT (info->object),
+				  "destroy",
+				  G_CALLBACK (while_realized_disconnecter),
+				  info);
 	
 	info->realized_widget = realized_widget;
 	info->realized_widget_destroy_handler = 
-		g_signal_connect (info->realized_widget,
-				    "destroy",
-				    G_CALLBACK (while_realized_disconnecter),
-				    info);
+		g_signal_connect (G_OBJECT (info->realized_widget),
+				  "destroy",
+				  G_CALLBACK (while_realized_disconnecter),
+				  info);
 	info->realized_widget_unrealized_handler = 
-		gtk_signal_connect_after (GTK_OBJECT (info->realized_widget),
-					  "unrealize",
-					  G_CALLBACK (while_realized_disconnecter),
-					  info);
+		g_signal_connect_after (G_OBJECT (info->realized_widget),
+					"unrealize",
+					G_CALLBACK (while_realized_disconnecter),
+					info);
 
-	info->signal_handler = gtk_signal_connect (info->object, name, callback, callback_data);
+	info->signal_handler = g_signal_connect (G_OBJECT (info->object),
+						 name, callback, callback_data);
 }
 
 /**
@@ -1115,361 +1083,6 @@ eel_gtk_widget_find_windowed_ancestor (GtkWidget *widget)
 	return widget;
 }
 
-
-
-/*following code shamelessly stolen from gtk*/
-static void
-rgb_to_hls (gdouble *r,
-            gdouble *g,
-            gdouble *b)
-{
-	gdouble min;
-	gdouble max;
-	gdouble red;
-	gdouble green;
-	gdouble blue;
-	gdouble h, l, s;
-	gdouble delta;
-
-	red = *r;
-	green = *g;
-	blue = *b;
-
-	if (red > green) {
-		if (red > blue)
-			max = red;
-		else
-			max = blue;
-		
-		if (green < blue)
-			min = green;
-		else
-			min = blue;
-	} else {
-		if (green > blue)
-			max = green;
-		else
-			max = blue;
-		
-		if (red < blue)
-			min = red;
-		else
-			min = blue;
-	}
-
-	l = (max + min) / 2;
-	s = 0;
-	h = 0;
-
-	if (max != min) {
-		if (l <= 0.5)
-			s = (max - min) / (max + min);
-		else
-			s = (max - min) / (2 - max - min);
-		
-		delta = max -min;
-		if (red == max)
-			h = (green - blue) / delta;
-		else if (green == max)
-			h = 2 + (blue - red) / delta;
-		else if (blue == max)
-			h = 4 + (red - green) / delta;
-		
-		h *= 60;
-		if (h < 0.0)
-			h += 360;
-	}
-	
-	*r = h;
-	*g = l;
-	*b = s;
-}
-
-static void
-hls_to_rgb (gdouble *h,
-            gdouble *l,
-            gdouble *s)
-{
-	gdouble hue;
-	gdouble lightness;
-	gdouble saturation;
-	gdouble m1, m2;
-	gdouble r, g, b;
-	
-	lightness = *l;
-	saturation = *s;
-
-	if (lightness <= 0.5)
-		m2 = lightness * (1 + saturation);
-	else
-		m2 = lightness + saturation - lightness * saturation;
-	m1 = 2 * lightness - m2;
-
-	if (saturation == 0) {
-		*h = lightness;
-		*l = lightness;
-		*s = lightness;
-	} else {
-		hue = *h + 120;
-		while (hue > 360)
-			hue -= 360;
-		while (hue < 0)
-			hue += 360;
-		
-		if (hue < 60)
-			r = m1 + (m2 - m1) * hue / 60;
-		else if (hue < 180)
-			r = m2;
-		else if (hue < 240)
-			r = m1 + (m2 - m1) * (240 - hue) / 60;
-		else
-			r = m1;
-
-		hue = *h;
-		while (hue > 360)
-			hue -= 360;
-		while (hue < 0)
-			hue += 360;
-		
-		if (hue < 60)
-			g = m1 + (m2 - m1) * hue / 60;
-		else if (hue < 180)
-			g = m2;
-		else if (hue < 240)
-			g = m1 + (m2 - m1) * (240 - hue) / 60;
-		else
-			g = m1;
-		
-		hue = *h - 120;
-		while (hue > 360)
-			hue -= 360;
-		while (hue < 0)
-			hue += 360;
-		
-		if (hue < 60)
-			b = m1 + (m2 - m1) * hue / 60;
-		else if (hue < 180)
-			b = m2;
-		else if (hue < 240)
-			b = m1 + (m2 - m1) * (240 - hue) / 60;
-		else
-			b = m1;
-		
-		*h = r;
-		*l = g;
-		*s = b;
-	}
-}
-
-void
-eel_gtk_style_shade (GdkColor *a,
-			  GdkColor *b,
-			  gdouble   k)
-{
-
-	gdouble red;
-	gdouble green;
-	gdouble blue;
-	
-	red = (gdouble) a->red / 65535.0;
-	green = (gdouble) a->green / 65535.0;
-	blue = (gdouble) a->blue / 65535.0;
-	
-	rgb_to_hls (&red, &green, &blue);
-
-	green *= k;
-	if (green > 1.0)
-		green = 1.0;
-	else if (green < 0.0)
-		green = 0.0;
-
-	blue *= k;
-	if (blue > 1.0)
-		blue = 1.0;
-	else if (blue < 0.0)
-		blue = 0.0;
-
-	hls_to_rgb (&red, &green, &blue);
-
-	b->red = red * 65535.0;
-	b->green = green * 65535.0;
-	b->blue = blue * 65535.0;
-}
-
-/**
- * eel_gtk_class_name_make_like_existing_type:
- * @class_name: The class name for the custom widget.
- * @existing_gtk_type: The GtkType of the existing GtkWidget.
- *
- * Make the given class name act like an existing GtkType for
- * gtk theme/style purposes.  This can be used by custom 
- * widget to emulate the styles of stock Gtk widgets.  For
- * example:
- *
- * eel_gtk_class_name_make_like_existing ("EelCustomButton",
- *                                             GTK_TYPE_BUTTON);
- *
- *
- * You should call this function only once from the class_init()
- * method of the custom widget.
- **/
-void
-eel_gtk_class_name_make_like_existing_type (const char *class_name,
-						 GtkType existing_gtk_type)
-{
-	GtkWidget *temporary;
-	GtkStyle *style;
-
-	g_return_if_fail (class_name != NULL);
-
-	temporary = gtk_widget_new (existing_gtk_type, NULL);
-	gtk_widget_ensure_style (temporary);
-		
-	style = gtk_widget_get_style (temporary);
-
-	if (style->rc_style != NULL) {
-		gtk_rc_add_widget_class_style (style->rc_style, class_name);
-	}
-		
-	gtk_object_sink (GTK_OBJECT (temporary));
-}
-
-/* helper function for eel_get_window_list_ordered_front_to_back () */
-static GtkWidget *
-window_at_or_below (int depth, Window xid, gboolean *keep_going)
-{
-	static Atom wm_state = 0;
-
-	GtkWidget *widget;
-
-	Atom actual_type;
-	int actual_format;
-	gulong nitems, bytes_after;
-	gulong *prop;
-
-	GdkWindow *window;
-	gpointer data;
-
-	Window root, parent, *children;
-	int nchildren, i;
-
-	if (wm_state == 0) {
-		wm_state = XInternAtom (GDK_DISPLAY (), "WM_STATE", False);
-	}
-
-	/* Check if the window is a top-level client window.
-	 * Windows will have a WM_STATE property iff they're top-level.
-	 */
-	if (XGetWindowProperty (GDK_DISPLAY (), xid, wm_state, 0, 1,
-				False, AnyPropertyType, &actual_type,
-				&actual_format, &nitems, &bytes_after,
-				(guchar **) &prop) == Success
-	    && prop != NULL && actual_format == 32 && prop[0] == NormalState)
-	{
-		/* Found a top-level window */
-
-		if (prop != NULL) {
-			XFree (prop);
-		}
-
-		/* Does GDK know anything about this window? */
-		window = gdk_window_lookup (xid);
-		if (window != NULL) {
-			gdk_window_get_user_data (window, &data);
-			if (data != NULL)
-			{
-				/* Found one of the widgets we're after */
-				*keep_going = FALSE;
-				return GTK_WIDGET (data);
-			}
-		}
-
-		/* No point in searching past here. It's a top-level
-		 * window, but not from this application.
-		 */
-		*keep_going = FALSE;
-		return NULL;
-	}
-
-	/* Not found a top-level window yet, so keep recursing. */
-	if (depth < MAXIMUM_WM_REPARENTING_DEPTH) {
-		if (XQueryTree (GDK_DISPLAY (), xid, &root,
-				&parent, &children, &nchildren) != 0)
-		{
-			widget = NULL;
-
-			for (i = 0; *keep_going && i < nchildren; i++) {
-				widget = window_at_or_below (depth + 1,
-							     children[i],
-							     keep_going);
-			}
-
-			if (children != NULL) {
-				XFree (children);
-			}
-
-			if (! *keep_going) {
-				return widget;
-			}
-		}
-	}
-
-	return NULL;
-}
-
-/* eel_get_window_list_ordered_front_to_back:
- *
- * Return a list of GtkWindows's, representing the stacking order (top to
- * bottom) of all windows (known to the local GDK).
- *
- * (Involves a large number of X server round trips, so call sparingly)
- */
-GList *
-eel_get_window_list_ordered_front_to_back (void)
-{
-	Window root, parent, *children;
-	int nchildren, i;
-	GList *windows;
-	GtkWidget *widget;
-	gboolean keep_going;
-
-	/* There's a possibility that a window will be closed in
-	 * the period between us querying the child-of-root windows
-	 * and getting round to search _their_ children. So arrange
-	 * for errors to be caught and ignored.
-	 */
-
-	gdk_error_trap_push ();
-
-	windows = NULL;
-
-	if (XQueryTree (GDK_DISPLAY (), GDK_ROOT_WINDOW (),
-			&root, &parent, &children, &nchildren) != 0)
-	{
-		for (i = 0; i < nchildren; i++) {
-			keep_going = TRUE;
-			widget = window_at_or_below (0, children[i],
-						     &keep_going);
-			if (widget != NULL) {
-				/* XQueryTree returns window in bottom ->
-				 * top order, so consing up the list in
-				 * the normal manner will reverse this
-				 * giving the desired top -> bottom order
-				 */
-				windows = g_list_prepend (windows, widget);
-			}
-		}
-		if (children != NULL) {
-			XFree (children);
-		}
-	}
-
-	gdk_flush ();
-	gdk_error_trap_pop ();
-
-	return windows;
-}
-
 /* eel_gtk_get_system_font:
  *
  * Return the system font as selected in the control center. Need to 
@@ -1495,136 +1108,6 @@ eel_gtk_get_system_font (void)
 	return font;
 }
 
-/**
- * eel_gtk_widget_standard_realize:
- *
- * @widget: A GtkWidget (must be unrealized).
- *
- * A standard implementation of GtkWidget::realize for widgets
- * that need a GdkWindow (GTK_WIDGET_NO_WINDOW (widget) == FALSE)
- * 
- * You should call gtk_widget_set_events() in your "GtkWidget::initialize"
- * method to set the event mask for your widget.
- */
-void
-eel_gtk_widget_standard_realize (GtkWidget *widget)
-{
-	GdkWindowAttr attributes;
-	gint attributes_mask;
-	gint border_width;
-	
-	g_return_if_fail (GTK_IS_WIDGET (widget));
-	g_return_if_fail (!GTK_WIDGET_REALIZED (widget));
-
-	GTK_WIDGET_SET_FLAGS (widget, GTK_REALIZED);
-
-	/* Its a little weird to check for the specific container type
-	 * here, but it makes this function convenient to use for
-	 * for containers as well.
-	 */
-	border_width = 
-		GTK_IS_CONTAINER (widget) ?
-		GTK_CONTAINER (widget)->border_width :
-		0;
-	
-	attributes.x = widget->allocation.x + border_width;
-	attributes.y = widget->allocation.y + border_width;
-	attributes.width = widget->allocation.width - 2 * border_width;
-	attributes.height = widget->allocation.height - 2 * border_width;
-	attributes.window_type = GDK_WINDOW_CHILD;
-	attributes.wclass = GDK_INPUT_OUTPUT;
-	attributes.visual = gtk_widget_get_visual (widget);
-	attributes.colormap = gtk_widget_get_colormap (widget);
-	attributes.event_mask = gtk_widget_get_events (widget);
-	
-	attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
-	
-	widget->window = gdk_window_new (gtk_widget_get_parent_window (widget), &attributes, attributes_mask);
-	gdk_window_set_user_data (widget->window, widget);
-	
-	widget->style = gtk_style_attach (widget->style, widget->window);
-	gtk_style_set_background (widget->style, widget->window, GTK_STATE_NORMAL);
-}
-
-/**
- * eel_gtk_bin_standard_size_allocate:
- *
- * @widget: A GtkBin widget.
- * @allocation: GtkAllocation pointer from size_allocate method.
- *
- * An implementation of GtkWidget::size_allocate for GtkBin widgets.
- */
-void
-eel_gtk_bin_standard_size_allocate (GtkWidget *widget,
-				    GtkAllocation *allocation)
-{
-	GtkWidget *child;
-	GtkAllocation child_allocation;
-	
-	g_return_if_fail (GTK_IS_BIN (widget));
-	g_return_if_fail (allocation != NULL);
-
-	child = GTK_BIN (widget)->child;
-	
-	if (child != NULL) {
-		g_return_if_fail (GTK_IS_WIDGET (child));
-	}
-	
-	widget->allocation = *allocation;
-	
-	child_allocation.x = 0;
-	child_allocation.y = 0;
-	child_allocation.width = MAX (allocation->width - GTK_CONTAINER (widget)->border_width * 2, 0);
-	child_allocation.height = MAX (allocation->height - GTK_CONTAINER (widget)->border_width * 2, 0);
-	
-	if (GTK_WIDGET_REALIZED (widget)) {
-		gdk_window_move_resize (widget->window,
-					allocation->x + GTK_CONTAINER (widget)->border_width,
-					allocation->y + GTK_CONTAINER (widget)->border_width,
-					child_allocation.width,
-					child_allocation.height);
-	}
-	
-	if (child != NULL) {
-		gtk_widget_size_allocate (child, &child_allocation);
-	}
-}
-
-/**
- * eel_gtk_bin_standard_size_request:
- *
- * @container: A GtkContainer widget.
- * @requisition: GtkRequisition pointer from size_request method.
- *
- * An implementation of GtkWidget::size_request for GtkBin widgets.
- */
-void
-eel_gtk_bin_standard_size_request (GtkWidget *widget,
-				   GtkRequisition *requisition)
-{
-	GtkRequisition child_requisition;
-	GtkWidget *child;
-	
-	g_return_if_fail (GTK_IS_BIN (widget));
-	g_return_if_fail (requisition != NULL);
-
-	child = GTK_BIN (widget)->child;
-
-	if (child != NULL) {
-		g_return_if_fail (GTK_IS_WIDGET (child));
-	}
-	
-	requisition->width = GTK_CONTAINER (widget)->border_width * 2;
-	requisition->height = GTK_CONTAINER (widget)->border_width * 2;
-	
-	if (child != NULL && GTK_WIDGET_VISIBLE (child)) {
-		gtk_widget_size_request (child, &child_requisition);
-		
-		requisition->width += child_requisition.width;
-		requisition->height += child_requisition.height;
-	}
-}
-
 static PangoContext *
 create_pango_ft2_context (PangoContext *base_context)
 {
@@ -1658,3 +1141,32 @@ eel_gtk_widget_get_pango_ft2_context (GtkWidget *widget)
 	
 	return context;
 }
+
+void
+eel_gtk_widget_get_button_event_location (GtkWidget *widget,
+					  const GdkEventButton *event,
+					  int *x,
+					  int *y)
+{
+	int window_x, window_y;
+
+	g_return_if_fail (GTK_IS_WIDGET (widget));
+	g_return_if_fail (event != NULL);
+
+	gdk_window_get_position (event->window, &window_x, &window_y);
+	if (x != NULL) {
+		*x = event->x + window_x - widget->allocation.x;
+	}
+	if (y != NULL) {
+		*y = event->y + window_y - widget->allocation.y;
+	}
+}
+
+void
+eel_gtk_widget_get_motion_event_location (GtkWidget *widget,
+					  const GdkEventMotion *event,
+					  int *x,
+					  int *y)
+{
+	eel_gtk_widget_get_button_event_location (widget, (const GdkEventButton *) event, x, y);
+}
