@@ -267,8 +267,7 @@ preferences_item_update_custom (EelPreferencesItem *item)
 {
 	g_return_if_fail (EEL_IS_PREFERENCES_ITEM (item));
 
-	gtk_signal_emit (GTK_OBJECT (item),
-			 signals[CUSTOM_UPDATE_DISPLAYED_VALUE]);
+	g_signal_emit (G_OBJECT (item), signals[CUSTOM_UPDATE_DISPLAYED_VALUE], 0);
 }
 
 /* This callback is called whenever the preference value changes, so that we can
@@ -1012,8 +1011,8 @@ preferences_item_update_displayed_value (EelPreferencesItem *item)
 		connection = node->data;
 		g_assert (GTK_IS_WIDGET (connection->widget));
 		
-		gtk_signal_handler_block (GTK_OBJECT (connection->widget),
-					  connection->signal_id);
+		g_signal_handler_block (G_OBJECT (connection->widget),
+					connection->signal_id);
 	}
 
 	/* Update the child widget according to the item type */
@@ -1064,8 +1063,8 @@ preferences_item_update_displayed_value (EelPreferencesItem *item)
 		connection = node->data;
 		g_assert (GTK_IS_WIDGET (connection->widget));
 		
-		gtk_signal_handler_unblock (GTK_OBJECT (connection->widget),
-					    connection->signal_id);
+		g_signal_handler_unblock (G_OBJECT (connection->widget),
+					  connection->signal_id);
 	}
 }
 
@@ -1324,10 +1323,10 @@ eel_preferences_item_set_description (EelPreferencesItem *item,
 		/* Padding doesnt have a description */
 		break;
 	case EEL_PREFERENCE_ITEM_CUSTOM:
-		gtk_signal_emit (GTK_OBJECT (item),
-				 signals[CUSTOM_DESCRIPTION_CHANGED],
-				 item->details->main_child,
-				 description);
+		g_signal_emit (G_OBJECT (item),
+			       signals[CUSTOM_DESCRIPTION_CHANGED], 0,
+			       item->details->main_child,
+			       description);
 		break;
 	default:
 		g_assert_not_reached ();
@@ -1341,23 +1340,25 @@ eel_preferences_item_class_init (EelPreferencesItemClass *class)
 
 	/* Signals */
 	signals[CUSTOM_UPDATE_DISPLAYED_VALUE] = 
-		gtk_signal_new ("custom_update_displayed_value",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (class),
-				GTK_SIGNAL_OFFSET (EelPreferencesItemClass, custom_update_displayed_value),
-				gtk_marshal_VOID__VOID,
-				G_TYPE_NONE, 
-				0);
+		g_signal_new ("custom_update_displayed_value",
+			      G_TYPE_FROM_CLASS (class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (EelPreferencesItemClass, custom_update_displayed_value),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE, 
+			      0);
 	signals[CUSTOM_DESCRIPTION_CHANGED] = 
- 		gtk_signal_new ("custom_description_changed",
- 				GTK_RUN_LAST,
- 				GTK_CLASS_TYPE (class),
-				GTK_SIGNAL_OFFSET (EelPreferencesItemClass, custom_update_description),
-				eel_marshal_VOID__POINTER_STRING,
- 				G_TYPE_NONE, 
- 				2,
- 				GTK_TYPE_OBJECT,
- 				GTK_TYPE_STRING);
+ 		g_signal_new ("custom_description_changed",
+			      G_TYPE_FROM_CLASS (class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (EelPreferencesItemClass, custom_update_description),
+			      NULL, NULL,
+			      eel_marshal_VOID__POINTER_STRING,
+			      G_TYPE_NONE, 
+			      2,
+			      G_TYPE_OBJECT,
+			      G_TYPE_STRING);
 }
 
 static void
